@@ -77,7 +77,7 @@ class WaifuAioClient:
         if response.status==200:
             return infos
         else:
-            raise APIException(response.status,response.reason,infos['error'])
+            raise APIException(response.status,infos['message'])
 
     def _create_params(self,**kwargs):
         rt={k:','.join(i) if isinstance(i,list) else str(i) for k,i in kwargs.items() if i}
@@ -113,7 +113,7 @@ class WaifuAioClient:
         data = await self._fetchtag('sfw',tag,raw,exclude,gif,many,top)
         return data
 
-    async def nsfw(self, tag: Union[int,str], raw: bool=False, exclude: List[str]=None, gif: bool=None, top: bool=None):
+    async def nsfw(self, tag: Union[int,str], raw: bool=False, exclude: List[str]=None, gif: bool=None, many: bool=None, top: bool=None):
         """Gets a single or multiple unique NSFW (Not Safe for Work) images of the specific category.
         Args:
             tag: The tag to request.
